Version

Enum Version 

pub enum Version {
    V1(Vec<u8>),
}

Variants



V1(Vec<u8>)

Expected to be an ECIES encrypted SignedPayload

Implementations

Source

impl Version

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Version>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.